====================
Module: pyhasse.lpom
====================

* Free software: MIT license
* Documentation: https://pyhasse.org

Features
--------

LPOM stands for Local Partial Order Model.

LPOM0 and LPOMext are approximations to calculate the
average height, hav, of partially ordered sets (posets).

Calculate:

- Averaged height
- Averaged height extended
- Objects averaged height0
- Objects averaged height extended
